@@ -53,12 +53,15 @@ import static com.openexchange.google.api.client.GoogleApiClients.REFRESH_THRESH
 import java.io.IOException;
 import com.google.api.client.googleapis.auth.oauth2.GoogleCredential;
 import com.google.api.services.gmail.Gmail;
+import com.google.api.services.gmail.Gmail.Builder;
 import com.google.api.services.gmail.model.Profile;
 import com.openexchange.exception.OXException;
 import com.openexchange.google.api.client.GoogleApiClients;
 import com.openexchange.mail.autoconfig.Autoconfig;
 import com.openexchange.mail.autoconfig.ImmutableAutoconfig;
+import com.openexchange.mail.oauth.DefaultTokenInfo;
 import com.openexchange.mail.oauth.MailOAuthProvider;
+import com.openexchange.mail.oauth.TokenInfo;
 import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
@@ -91,14 +94,14 @@ public class GoogleMailOAuthProvider implements MailOAuthProvider {
 
             // Determine E-Mail address from "user/me" end-point
             GoogleCredential credentials = com.openexchange.google.api.client.GoogleApiClients.getCredentials(oauthAccountToUse, session);
-            Gmail gmail = new Gmail.Builder(credentials.getTransport(), credentials.getJsonFactory(), credentials).setApplicationName(GoogleApiClients.getGoogleProductName(session)).build();
+            Gmail gmail = new Builder(credentials.getTransport(), credentials.getJsonFactory(), credentials).setApplicationName(GoogleApiClients.getGoogleProductName(session)).build();
             Profile profile = gmail.users().getProfile("me").execute();
             String email = profile.getEmailAddress();
 
             ImmutableAutoconfig.Builder builder = ImmutableAutoconfig.builder();
             builder.username(email);
-            builder.mailOAuthId(oauthAccount.getId()).mailPort(993).mailProtocol("imap").mailSecure(true).mailServer("imap.gmail.com").mailStartTls(false);
-            builder.transportOAuthId(oauthAccount.getId()).transportPort(587).transportProtocol("smtp").transportSecure(false).transportServer("smtp.gmail.com").transportStartTls(true);
+            builder.mailOAuthId(oauthAccount.getId()).mailPort(Integer.valueOf(993)).mailProtocol("imap").mailSecure(Boolean.TRUE).mailServer("imap.gmail.com").mailStartTls(false);
+            builder.transportOAuthId(oauthAccount.getId()).transportPort(Integer.valueOf(-1)).transportProtocol("gmailsend").transportSecure(Boolean.FALSE).transportServer("www.googleapis.com");
             return builder.build();
         } catch (IOException e) {
             throw OAuthExceptionCodes.IO_ERROR.create(e, e.getMessage());
@@ -106,7 +109,7 @@ public class GoogleMailOAuthProvider implements MailOAuthProvider {
     }
 
     @Override
-    public String getTokenFor(OAuthAccount oauthAccount, Session session) throws OXException {
+    public TokenInfo getTokenFor(OAuthAccount oauthAccount, Session session) throws OXException {
         // Ensure not expired
         String key = "oauth.google.expiry." + oauthAccount.getId();
 
@@ -117,7 +120,7 @@ public class GoogleMailOAuthProvider implements MailOAuthProvider {
                 Long stamp = (Long) object;
                 if ((stamp.longValue() - System.currentTimeMillis()) >= REFRESH_THRESHOLD) {
                     // More than 1 minute to go
-                    return oauthAccount.getToken();
+                    return DefaultTokenInfo.newXOAUTH2TokenInfoFor(oauthAccount.getToken());
                 }
 
                 // Expired... Drop cached value.
@@ -131,7 +134,7 @@ public class GoogleMailOAuthProvider implements MailOAuthProvider {
             if (expirySeconds >= REFRESH_THRESHOLD) {
                 // More than 1 minute to go
                 session.setParameter(key, Long.valueOf(System.currentTimeMillis() + (expirySeconds * 1000)));
-                return oauthAccount.getToken();
+                return DefaultTokenInfo.newXOAUTH2TokenInfoFor(oauthAccount.getToken());
             }
         }
 
@@ -141,7 +144,7 @@ public class GoogleMailOAuthProvider implements MailOAuthProvider {
         if (null != newAccount) {
             oauthAccountToUse = newAccount;
         }
-        return oauthAccountToUse.getToken();
+        return DefaultTokenInfo.newXOAUTH2TokenInfoFor(oauthAccountToUse.getToken());
     }
 
     @Override
