@@ -85,6 +85,7 @@ import org.scribe.builder.api.YahooApi;
 import org.scribe.model.Token;
 import org.scribe.model.Verifier;
 import com.openexchange.context.ContextService;
+import com.openexchange.crypto.CryptoErrorMessage;
 import com.openexchange.crypto.CryptoService;
 import com.openexchange.database.Databases;
 import com.openexchange.database.provider.DBProvider;
@@ -102,6 +103,7 @@ import com.openexchange.net.ssl.exception.SSLExceptionCode;
 import com.openexchange.oauth.DefaultOAuthAccount;
 import com.openexchange.oauth.API;
 import com.openexchange.oauth.HostInfo;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthConstants;
 import com.openexchange.oauth.OAuthEventConstants;
@@ -353,7 +355,9 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                     }
 
                     String prevCbUrl = cbUrl;
-                    cbUrl = currentHost.injectRoute(new StringBuilder(uri.getScheme()).append("://").append(uri.getHost()).append(path).toString());
+                    String deferredBaseURL = new StringBuilder(uri.getScheme()).append("://").append(uri.getHost()).append(path).toString();
+                    // For the Twitter API we need to inject the route as URL parameter instead of path segment, see Bug 59098
+                    cbUrl = KnownApi.TWITTER.getServiceId().equals(serviceMetaData) ? currentHost.injectRouteAsParameter(deferredBaseURL) : currentHost.injectRoute(deferredBaseURL);
 
                     org.scribe.oauth.OAuthService service = getScribeService(metaData, cbUrl, session, scopes);
                     scribeToken = service.getRequestToken();
@@ -725,11 +729,21 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
             if (!rs.next()) {
                 throw OAuthExceptionCodes.ACCOUNT_NOT_FOUND.create(Integer.valueOf(accountId), Integer.valueOf(user), Integer.valueOf(contextId));
             }
-            final DefaultOAuthAccount account = new DefaultOAuthAccount();
+
+            DefaultOAuthAccount account = new DefaultOAuthAccount();
             account.setId(accountId);
-            account.setDisplayName(rs.getString(1));
-            account.setToken(encryptionService.decrypt(session, rs.getString(2), new PWUpdate("accessToken", contextId, accountId)));
-            account.setSecret(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessSecret", contextId, accountId)));
+            String displayName = rs.getString(1);
+            account.setDisplayName(displayName);
+            try {
+                account.setToken(encryptionService.decrypt(session, rs.getString(2), new PWUpdate("accessToken", contextId, accountId)));
+                account.setSecret(encryptionService.decrypt(session, rs.getString(3), new PWUpdate("accessSecret", contextId, accountId)));
+            } catch (OXException e) {
+                if (false == CryptoErrorMessage.BadPassword.equals(e)) {
+                    throw e;
+                }
+
+                throw OAuthExceptionCodes.INVALID_ACCOUNT_EXTENDED.create(e.getCause(), displayName, accountId);
+            }
 
             account.setMetaData(registry.getService(rs.getString(4), user, contextId));
             String scopes = rs.getString(5);
@@ -804,7 +818,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
             final ArrayList<Object> values = new ArrayList<Object>(SQLStructure.OAUTH_COLUMN.values().length);
             final UPDATE update = SQLStructure.updateAccount(account, contextId, user, values);
             /*
-             * Execute UPDATE command
+             * Get connection
              */
             Context ctx = getContext(contextId);
             Connection writeCon = getConnection(false, ctx);
@@ -832,7 +846,7 @@ public class OAuthServiceImpl implements OAuthService, SecretEncryptionStrategy<
                  * Commit
                  */
                 writeCon.commit();
-                
+
                 // No need to re-authorise if access not present
                 OAuthAccess access = oAuthAccessRegistry.get(contextId, user);
                 if (access != null) {
