@@ -54,9 +54,6 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthService;
@@ -70,10 +67,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(method = RequestMethod.GET, name = "all", description = "Get all OAuth accounts", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "serviceId", optional=true, description = "The optional service meta data identifier. If missing all accounts of all services are returned; otherwise all accounts of specified service are returned.")
-}, responseDescription = "An array with account data. Each array element is a JSON object describing an OAuth account as specified in OAuth account data.")
 public final class AllAction extends AbstractOAuthAJAXActionService {
 
     /**
@@ -105,7 +98,7 @@ public final class AllAction extends AbstractOAuthAJAXActionService {
              */
             final JSONArray jsonArray = new JSONArray();
             for (final OAuthAccount oAuthAccount : accounts) {
-                jsonArray.put(AccountWriter.write(oAuthAccount));
+                jsonArray.put(AccountWriter.write(oAuthAccount, session));
             }
             /*
              * Return appropriate result
