@@ -51,15 +51,14 @@ package com.openexchange.oauth.json.oauthaccount.actions;
 
 import java.io.IOException;
 import java.util.Map;
+import java.util.Set;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.DispatcherNotes;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
+import com.openexchange.ajax.requesthandler.SecureContentWrapper;
 import com.openexchange.exception.OXException;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
@@ -69,6 +68,7 @@ import com.openexchange.oauth.OAuthServiceMetaData;
 import com.openexchange.oauth.OAuthServiceMetaDataRegistry;
 import com.openexchange.oauth.json.oauthaccount.AccountField;
 import com.openexchange.oauth.json.oauthaccount.AccountWriter;
+import com.openexchange.oauth.scope.OAuthScope;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.servlet.http.Tools;
 import com.openexchange.tools.session.ServerSession;
@@ -78,13 +78,6 @@ import com.openexchange.tools.session.ServerSession;
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
-@Action(method = RequestMethod.PUT, name = "create", description = "Create an OAuth account", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "oauth_token", description = "The request token from preceeding OAuth interaction."),
-    @Parameter(name = "uuid", description = "The UUID of the preceeding OAuth interaction."),
-    @Parameter(name = "oauth_verfifier", description = "The verifier string which confirms that user granted access."),
-    @Parameter(name = "displayName", description = "The display name for the new account.")
-}, responseDescription = "A JSON object describing the newly created OAuth account as specified in OAuth account data.")
 @DispatcherNotes(noSecretCallback = true)
 public final class CreateAction extends AbstractOAuthTokenAction {
 
@@ -113,10 +106,13 @@ public final class CreateAction extends AbstractOAuthTokenAction {
             }
             final Map<String, Object> arguments = processOAuthArguments(request, session, service);
 
+            // Get the scopes
+            Set<OAuthScope> scopes = getScopes(request, serviceId);
+
             // By now it doesn't matter which interaction type is passed
             OAuthAccount newAccount;
             try {
-                newAccount = oAuthService.createAccount(serviceId, OAuthInteractionType.CALLBACK, arguments, session.getUserId(), session.getContextId());
+                newAccount = oAuthService.createAccount(serviceId, OAuthInteractionType.CALLBACK, arguments, session.getUserId(), session.getContextId(), scopes);
             } catch (OXException e) {
                 // Create attempt failed
                 HttpServletResponse response = request.optHttpServletResponse();
@@ -133,13 +129,11 @@ public final class CreateAction extends AbstractOAuthTokenAction {
             }
 
             // Write as JSON
-            final JSONObject jsonAccount = AccountWriter.write(newAccount);
-
+            final JSONObject jsonAccount = AccountWriter.write(newAccount, session);
             // Return appropriate result
-            return new AJAXRequestResult(jsonAccount);
+            return new AJAXRequestResult(new SecureContentWrapper(jsonAccount, "json"), SecureContentWrapper.CONTENT_TYPE);
         } catch (final JSONException e) {
-            throw AjaxExceptionCodes.JSON_ERROR.create( e, e.getMessage());
+            throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
         }
     }
-
 }
