@@ -50,14 +50,17 @@
 package com.openexchange.oauth.json.oauthaccount.actions;
 
 import static com.openexchange.java.Strings.isEmpty;
+import static com.openexchange.java.util.Tools.getUnsignedInteger;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.net.InetAddress;
 import java.net.URLEncoder;
 import java.net.UnknownHostException;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.Locale;
 import java.util.Map;
+import java.util.Set;
 import java.util.UUID;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
@@ -67,25 +70,23 @@ import com.openexchange.ajax.requesthandler.AJAXRequestData;
 import com.openexchange.ajax.requesthandler.AJAXRequestDataTools;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.ajax.requesthandler.AJAXRequestResult.ResultType;
-import com.openexchange.documentation.RequestMethod;
-import com.openexchange.documentation.annotations.Action;
-import com.openexchange.documentation.annotations.Parameter;
 import com.openexchange.exception.OXException;
 import com.openexchange.exception.OXExceptionStrings;
 import com.openexchange.groupware.notify.hostname.HostnameService;
 import com.openexchange.i18n.tools.StringHelper;
+import com.openexchange.oauth.HostInfo;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthConstants;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.OAuthInteraction;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthToken;
+import com.openexchange.oauth.OAuthUtil;
 import com.openexchange.oauth.Parameterizable;
-import com.openexchange.oauth.json.AbstractOAuthAJAXActionService;
 import com.openexchange.oauth.json.Services;
-import com.openexchange.oauth.json.Tools;
 import com.openexchange.oauth.json.oauthaccount.AccountField;
 import com.openexchange.oauth.json.oauthaccount.AccountWriter;
+import com.openexchange.oauth.scope.OAuthScope;
 import com.openexchange.session.Session;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
@@ -94,12 +95,9 @@ import com.openexchange.tools.session.ServerSession;
  * {@link InitAction}
  *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
+ * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a> (refactoring)
  */
-@Action(method = RequestMethod.GET, name = "init", description = "Initialize creation of an OAuth account", parameters = {
-    @Parameter(name = "session", description = "A session ID previously obtained from the login module."),
-    @Parameter(name = "serviceId", description = "The service meta data identifier; e.g. \"com.openexchange.oauth.twitter\"")
-}, responseDescription = "An JSON representation of the resulting interaction providing needed information to complete account creation. See OAuth interaction data.")
-public final class InitAction extends AbstractOAuthAJAXActionService {
+public final class InitAction extends AbstractOAuthTokenAction {
 
     /**
      * Initializes a new {@link InitAction}.
@@ -123,104 +121,37 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
              */
             return reauthorizeCallbackAction(accountId, request, session);
         } catch (JSONException e) {
-            throw AjaxExceptionCodes.JSON_ERROR.create( e, e.getMessage());
+            throw AjaxExceptionCodes.JSON_ERROR.create(e, e.getMessage());
         }
     }
 
-    //FIXME: Refactor this. These methods are pretty similar. DRY
-
+    /**
+     * Creates an <code>init?action=create</code> call-back action
+     *
+     * @param request The {@link AJAXRequestData}
+     * @param session The server session
+     * @return the {@link AJAXRequestResult} containing the {@link OAuthInteraction} as a {@link JSONObject}
+     * @throws OXException if the call-back action cannot be created
+     */
     private AJAXRequestResult createCallbackAction(AJAXRequestData request, ServerSession session) throws OXException {
         Locale locale = session.getUser().getLocale();
         try {
-            final OAuthService oAuthService = getOAuthService();
             /*
              * Parse parameters
              */
             final String serviceId = request.getParameter(AccountField.SERVICE_ID.getName());
             if (serviceId == null) {
-                throw AjaxExceptionCodes.MISSING_PARAMETER.create( AccountField.SERVICE_ID.getName());
+                throw AjaxExceptionCodes.MISSING_PARAMETER.create(AccountField.SERVICE_ID.getName());
             }
             final String name = AccountField.DISPLAY_NAME.getName();
             final String displayName = request.getParameter(name);
             if (isEmpty(displayName)) {
                 throw OAuthExceptionCodes.MISSING_DISPLAY_NAME.create();
             }
-            /*
-             * Generate UUID
-             */
-            final String uuid = UUID.randomUUID().toString();
-            /*
-             * OAuth token for session
-             */
-            final String oauthSessionToken = UUID.randomUUID().toString();
-            /*
-             * Compose call-back URL
-             */
-            final String callbackUrl;
-            {
-                final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
-                // Append query string
-                callbackUrlBuilder.append("?action=create");
-                callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
-                callbackUrlBuilder.append('&').append(name).append('=').append(urlEncode(displayName));
-                callbackUrlBuilder.append('&').append(AccountField.SERVICE_ID.getName()).append('=').append(urlEncode(serviceId));
-                callbackUrlBuilder.append('&').append(OAuthConstants.SESSION_PARAM_UUID).append('=').append(uuid);
-                callbackUrlBuilder.append('&').append(Session.PARAM_TOKEN).append('=').append(oauthSessionToken);
-                final String cb = request.getParameter("cb");
-                if (!isEmpty(cb)) {
-                	callbackUrlBuilder.append("&callback=").append(cb);
-                }
-                callbackUrl = callbackUrlBuilder.toString();
-            }
-            /*
-             * Invoke
-             */
-            final String currentHost = determineHost(request, session);
-            final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrl, currentHost, session);
-            final OAuthToken requestToken = interaction.getRequestToken();
-            /*
-             * Create a container to set some state information: Request token's secret, call-back URL, whatever
-             */
-            final Map<String, Object> oauthState = new HashMap<String, Object>();
-            if (interaction instanceof Parameterizable) {
-                final Parameterizable params = (Parameterizable) interaction;
-                for (final String key : params.getParamterNames()) {
-                    final Object value = params.getParameter(key);
-                    if (null != value) {
-                        oauthState.put(key, value);
-                    }
-                }
-            }
-            oauthState.put(OAuthConstants.ARGUMENT_SECRET, requestToken.getSecret());
-            oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrl);
-            oauthState.put(OAuthConstants.ARGUMENT_CURRENT_HOST, currentHost);
-            oauthState.put(OAuthConstants.ARGUMENT_AUTH_URL, interaction.getAuthorizationURL());
-            session.setParameter(uuid, oauthState);
-            session.setParameter(Session.PARAM_TOKEN, oauthSessionToken);
-            /*
-             * Check redirect parameter
-             */
-            if (AJAXRequestDataTools.parseBoolParameter(request.getParameter("redirect"))) {
-                // Request for redirect
-                HttpServletResponse response = request.optHttpServletResponse();
-                if (null != response) {
-                    try {
-                        response.sendRedirect(interaction.getAuthorizationURL());
-                        //response.setStatus(HttpServletResponse.SC_MOVED_TEMPORARILY);
-                        return new AJAXRequestResult(AJAXRequestResult.DIRECT_OBJECT, "direct").setType(ResultType.DIRECT);
-                    } catch (IOException e) {
-                        throw OAuthExceptionCodes.IO_ERROR.create(e, e.getMessage());
-                    }
-                }
-            }
-            /*
-             * Write as JSON
-             */
-            final JSONObject jsonInteraction = AccountWriter.write(interaction, uuid);
-            /*
-             * Return appropriate result
-             */
-            return new AJAXRequestResult(jsonInteraction);
+            // Get the scopes
+            Set<OAuthScope> scopes = getScopes(request, serviceId);
+
+            return invokeInteraction(request, session, "create", -1, serviceId, scopes);
         } catch (OXException e) {
             if (Client.OX6_UI.getClientId().equals(session.getClient())) {
                 throw e;
@@ -239,13 +170,45 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         }
     }
 
+    /**
+     * Creates an <code>init?action=reauthorize</code> call-back action
+     *
+     * @param request The {@link AJAXRequestData}
+     * @param session The server session
+     * @return the {@link AJAXRequestResult} containing the {@link OAuthInteraction} as a {@link JSONObject}
+     * @throws OXException if the call-back action cannot be created
+     */
     private AJAXRequestResult reauthorizeCallbackAction(final String accountId, final AJAXRequestData request, final ServerSession session) throws OXException, JSONException {
         final OAuthService oAuthService = getOAuthService();
         /*
          * Get account by identifier
          */
-        final OAuthAccount account = oAuthService.getAccount(Tools.getUnsignedInteger(accountId), session, session.getUserId(), session.getContextId());
+        final OAuthAccount account = oAuthService.getAccount(getUnsignedInteger(accountId), session, session.getUserId(), session.getContextId());
         final String serviceId = account.getMetaData().getId();
+        // Get the scopes
+        Set<OAuthScope> scopesToEnable = getScopes(request, serviceId);
+        // Merge scopes
+        Set<OAuthScope> scopes = new HashSet<>();
+        scopes.addAll(account.getEnabledScopes());
+        scopes.addAll(scopesToEnable);
+
+        return invokeInteraction(request, session, "reauthorize", account.getId(), serviceId, scopes);
+    }
+
+    /**
+     * Processes and invokes the {@link OAuthInteraction}
+     *
+     * @param request The {@link AJAXRequestData}
+     * @param session The server {@link Session}
+     * @param action The action of the <code>init</code> call
+     * @param accountId The account identifier; -1 if not available (which indicates a <code>create</code> action.
+     * @param serviceId The OAuth service provider identifier
+     * @param scopes The {@link OAuthScope}s to enable
+     * @return the {@link AJAXRequestResult} containing the {@link OAuthInteraction} as a {@link JSONObject}
+     * @throws JSONException if a JSON error is occurred
+     * @throws OXException if a server error is occurred
+     */
+    private AJAXRequestResult invokeInteraction(AJAXRequestData request, ServerSession session, String action, int accountId, String serviceId, Set<OAuthScope> scopes) throws JSONException, OXException {
         /*
          * Generate UUID
          */
@@ -254,36 +217,19 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
          * OAuth token for session
          */
         final String oauthSessionToken = UUID.randomUUID().toString();
-        /*
-         * Compose call-back URL
-         */
-        final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
-        callbackUrlBuilder.append("?action=reauthorize");
-        callbackUrlBuilder.append("&id=").append(account.getId());
-        callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
-        {
-            final String name = AccountField.DISPLAY_NAME.getName();
-            final String displayName = request.getParameter(name);
-            if (displayName != null) {
-                callbackUrlBuilder.append('&').append(name).append('=').append(urlEncode(displayName));
-            }
-        }
-        callbackUrlBuilder.append('&').append(AccountField.SERVICE_ID.getName()).append('=').append(urlEncode(serviceId));
-        callbackUrlBuilder.append('&').append(OAuthConstants.SESSION_PARAM_UUID).append('=').append(uuid);
-        callbackUrlBuilder.append('&').append(Session.PARAM_TOKEN).append('=').append(oauthSessionToken);
-        final String cb = request.getParameter("cb");
-        if (!isEmpty(cb)) {
-        	callbackUrlBuilder.append("&callback=").append(cb);
-        }
+
+        String callbackUrl = composeCallbackURL(request, session, action, scopes, accountId, serviceId, uuid, oauthSessionToken);
+        OAuthService oauthService = getOAuthService();
         /*
          * Invoke
          */
-        final OAuthInteraction interaction = oAuthService.initOAuth(serviceId, callbackUrlBuilder.toString(), determineHost(request, session), session);
+        final HostInfo currentHost = determineHost(request, session);
+        final OAuthInteraction interaction = oauthService.initOAuth(serviceId, callbackUrl, currentHost, session, scopes);
         final OAuthToken requestToken = interaction.getRequestToken();
         /*
          * Create a container to set some state information: Request token's secret, call-back URL, whatever
          */
-        final Map<String, Object> oauthState = new HashMap<String, Object>();
+        final Map<String, Object> oauthState = new HashMap<>();
         if (interaction instanceof Parameterizable) {
             final Parameterizable params = (Parameterizable) interaction;
             for (final String key : params.getParamterNames()) {
@@ -294,7 +240,9 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
             }
         }
         oauthState.put(OAuthConstants.ARGUMENT_SECRET, requestToken.getSecret());
-        oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrlBuilder.toString());
+        oauthState.put(OAuthConstants.ARGUMENT_CALLBACK, callbackUrl);
+        oauthState.put(OAuthConstants.ARGUMENT_CURRENT_HOST, currentHost.getHost());
+        oauthState.put(OAuthConstants.ARGUMENT_ROUTE, currentHost.getRoute());
         oauthState.put(OAuthConstants.ARGUMENT_AUTH_URL, interaction.getAuthorizationURL());
         session.setParameter(uuid, oauthState);
         session.setParameter(Session.PARAM_TOKEN, oauthSessionToken);
@@ -324,7 +272,56 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         return new AJAXRequestResult(jsonInteraction);
     }
 
-    private static String urlEncode(final String s) {
+    private HostInfo determineHost(AJAXRequestData request, ServerSession session) {
+        return new HostInfo(determineHostName(request, session), request.getRoute());
+    }
+
+    /**
+     * Composes the call-back URL
+     *
+     * @param request The {@link AJAXRequestData}
+     * @param session The server {@link Session}
+     * @param action The action of the <code>init</code> call
+     * @param scopes The {@link OAuthScope}s to enable
+     * @param accountId The account identifier
+     * @param serviceId The OAuth service provider's identifier
+     * @param uuid The OAuthState UUID
+     * @param oauthSessionToken The OAuth token for the session
+     * @return The call-back URL as a String
+     */
+    private String composeCallbackURL(AJAXRequestData request, Session session, String action, Set<OAuthScope> scopes, int accountId, String serviceId, String uuid, String oauthSessionToken) {
+        final StringBuilder callbackUrlBuilder = request.constructURL(new StringBuilder(PREFIX.get().getPrefix()).append("oauth/accounts").toString(), true);
+        callbackUrlBuilder.append("?action=").append(action);
+        if (accountId >= 0) {
+            callbackUrlBuilder.append("&id=").append(accountId);
+        }
+        callbackUrlBuilder.append("&respondWithHTML=true&session=").append(session.getSessionID());
+        {
+            final String name = AccountField.DISPLAY_NAME.getName();
+            final String displayName = request.getParameter(name);
+            if (displayName != null) {
+                callbackUrlBuilder.append('&').append(name).append('=').append(urlEncode(displayName));
+            }
+        }
+        callbackUrlBuilder.append('&').append(AccountField.SERVICE_ID.getName()).append('=').append(urlEncode(serviceId));
+        callbackUrlBuilder.append('&').append(OAuthConstants.SESSION_PARAM_UUID).append('=').append(uuid);
+        callbackUrlBuilder.append('&').append(Session.PARAM_TOKEN).append('=').append(oauthSessionToken);
+        callbackUrlBuilder.append('&').append("scopes").append('=').append(OAuthUtil.oxScopesToString(scopes));
+        final String cb = request.getParameter("cb");
+        if (!isEmpty(cb)) {
+            callbackUrlBuilder.append("&callback=").append(cb);
+        }
+
+        return callbackUrlBuilder.toString();
+    }
+
+    /**
+     * URL encodes the specified string
+     *
+     * @param s The string to URL encode
+     * @return The URL encoded string
+     */
+    private String urlEncode(final String s) {
         try {
             return URLEncoder.encode(s, "ISO-8859-1");
         } catch (final UnsupportedEncodingException e) {
@@ -332,7 +329,15 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         }
     }
 
-    private static String determineHost(AJAXRequestData requestData, ServerSession session) {
+    /**
+     * Determines the host. Starts by the {@link HostnameService}, then from the specified {@link AJAXRequestData},
+     * then Java and sets it to localhost as a last resort.
+     *
+     * @param requestData The {@link AJAXRequestData}
+     * @param session The groupware {@link Session}
+     * @return The hostname
+     */
+    private String determineHostName(AJAXRequestData requestData, ServerSession session) {
         String hostName = null;
         /*
          * Ask hostname service if available
@@ -371,5 +376,4 @@ public final class InitAction extends AbstractOAuthAJAXActionService {
         }
         return requestData.getHostname();
     }
-
 }
