@@ -54,7 +54,7 @@ import java.util.Collection;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.exception.OXException;
-import com.openexchange.oauth.OAuthHTTPClientFactory;
+import com.openexchange.oauth.http.OAuthHTTPClientFactory;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 
