@@ -52,13 +52,16 @@ package com.openexchange.oauth.twitter;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.Map;
+import java.util.Set;
 import org.scribe.builder.api.Api;
 import org.scribe.builder.api.TwitterApi;
 import com.openexchange.exception.OXException;
-import com.openexchange.oauth.API;
-import com.openexchange.oauth.AbstractExtendedScribeAwareOAuthServiceMetaData;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthToken;
+import com.openexchange.oauth.impl.AbstractExtendedScribeAwareOAuthServiceMetaData;
+import com.openexchange.oauth.scope.OAuthScope;
 import com.openexchange.server.ServiceLookup;
+import com.openexchange.session.Session;
 
 /**
  * {@link OAuthServiceMetaDataTwitterImpl}
@@ -72,22 +75,7 @@ public class OAuthServiceMetaDataTwitterImpl extends AbstractExtendedScribeAware
      * Initializes a new {@link OAuthServiceMetaDataTwitterImpl}.
      */
     public OAuthServiceMetaDataTwitterImpl(ServiceLookup services) {
-        super(services, "com.openexchange.oauth.twitter", "Twitter", true, true);
-    }
-
-    @Override
-    public String getDisplayName() {
-        return "Twitter";
-    }
-
-    @Override
-    public String getId() {
-        return "com.openexchange.oauth.twitter";
-    }
-
-    @Override
-    public API getAPI() {
-        return API.TWITTER;
+        super(services, KnownApi.TWITTER, true, true, TwitterOAuthScope.values());
     }
 
     @Override
@@ -106,7 +94,7 @@ public class OAuthServiceMetaDataTwitterImpl extends AbstractExtendedScribeAware
     }
 
     @Override
-    public String processAuthorizationURL(final String authUrl) {
+    public String processAuthorizationURL(final String authUrl, Session session) {
         return authUrl;
     }
 
@@ -121,7 +109,7 @@ public class OAuthServiceMetaDataTwitterImpl extends AbstractExtendedScribeAware
     }
 
     @Override
-    public OAuthToken getOAuthToken(final Map<String, Object> arguments) throws OXException {
+    public OAuthToken getOAuthToken(final Map<String, Object> arguments, Set<OAuthScope> scopes) throws OXException {
         return null;
     }
 }
