@@ -52,10 +52,11 @@ package com.openexchange.oauth.yahoo.internal;
 import java.util.Collection;
 import java.util.Collections;
 import org.scribe.builder.api.Api;
-import org.scribe.builder.api.YahooApi;
 import com.openexchange.http.deferrer.DeferringURLService;
-import com.openexchange.oauth.API;
-import com.openexchange.oauth.AbstractScribeAwareOAuthServiceMetaData;
+import com.openexchange.oauth.HostInfo;
+import com.openexchange.oauth.KnownApi;
+import com.openexchange.oauth.impl.AbstractExtendedScribeAwareOAuthServiceMetaData;
+import com.openexchange.oauth.yahoo.YahooOAuthScope;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 
@@ -66,29 +67,29 @@ import com.openexchange.session.Session;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  * @author <a href="mailto:ioannis.chouklis@open-xchange.com">Ioannis Chouklis</a>
  */
-public class OAuthServiceMetaDataYahooImpl extends AbstractScribeAwareOAuthServiceMetaData {
+public class OAuthServiceMetaDataYahooImpl extends AbstractExtendedScribeAwareOAuthServiceMetaData {
 
     public OAuthServiceMetaDataYahooImpl(ServiceLookup services) {
-        super(services, "com.openexchange.oauth.yahoo", "Yahoo");
+        super(services, KnownApi.YAHOO, YahooOAuthScope.values());
     }
 
     @Override
-    public String modifyCallbackURL(String callbackUrl, String currentHost, Session session) {
+    public String modifyCallbackURL(String callbackUrl, HostInfo currentHost, Session session) {
         DeferringURLService deferrer = services.getService(DeferringURLService.class);
         if (deferrer == null) {
             return callbackUrl;
         }
-        return deferrer.getDeferredURL(callbackUrl, session.getUserId(), session.getContextId());
-    }
-
-    @Override
-    public API getAPI() {
-        return API.YAHOO;
+        return injectRoute(deferrer.getDeferredURL(callbackUrl, session.getUserId(), session.getContextId()), currentHost.getRoute());
     }
 
     @Override
     public Class<? extends Api> getScribeService() {
-        return YahooApi.class;
+        return YahooApi2.class;
+    }
+
+    @Override
+    public boolean needsRequestToken() {
+        return false;
     }
 
     @Override
@@ -98,6 +99,6 @@ public class OAuthServiceMetaDataYahooImpl extends AbstractScribeAwareOAuthServi
 
     @Override
     protected Collection<OAuthPropertyID> getExtraPropertyNames() {
-        return Collections.emptyList();
+        return Collections.singletonList(OAuthPropertyID.redirectUrl);
     }
 }
