@@ -49,15 +49,25 @@
 
 package com.openexchange.oauth.yahoo.osgi;
 
+import java.util.Dictionary;
+import java.util.Hashtable;
+import org.osgi.service.event.EventConstants;
+import org.osgi.service.event.EventHandler;
 import com.openexchange.config.ConfigurationService;
 import com.openexchange.config.Reloadable;
 import com.openexchange.http.deferrer.DeferringURLService;
+import com.openexchange.oauth.OAuthAccountDeleteListener;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthServiceMetaData;
+import com.openexchange.oauth.access.OAuthAccessRegistryService;
+import com.openexchange.oauth.scope.OAuthScopeRegistry;
+import com.openexchange.oauth.yahoo.YahooOAuthScope;
 import com.openexchange.oauth.yahoo.YahooService;
+import com.openexchange.oauth.yahoo.access.YahooAccessEventHandler;
 import com.openexchange.oauth.yahoo.internal.OAuthServiceMetaDataYahooImpl;
 import com.openexchange.oauth.yahoo.internal.YahooServiceImpl;
 import com.openexchange.osgi.HousekeepingActivator;
+import com.openexchange.sessiond.SessiondEventConstants;
 import com.openexchange.threadpool.ThreadPoolService;
 
 /**
@@ -95,11 +105,12 @@ public class YahooOAuthActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { ConfigurationService.class, OAuthService.class, DeferringURLService.class, ThreadPoolService.class };
+        return new Class<?>[] { ConfigurationService.class, OAuthService.class, DeferringURLService.class, ThreadPoolService.class, OAuthScopeRegistry.class, OAuthAccessRegistryService.class };
     }
 
     @Override
     protected void startBundle() throws Exception {
+        Services.setServices(this);
         oauthService = getService(OAuthService.class);
         oAuthMetaData = new OAuthServiceMetaDataYahooImpl(this);
         registerService(OAuthServiceMetaData.class, oAuthMetaData);
@@ -107,8 +118,24 @@ public class YahooOAuthActivator extends HousekeepingActivator {
         LOG.info("OAuthServiceMetaData for Yahoo was started");
 
         final YahooService yahooService = new YahooServiceImpl(this);
-
         registerService(YahooService.class, yahooService);
+        // Register the delete listener
+        registerService(OAuthAccountDeleteListener.class, (OAuthAccountDeleteListener) yahooService);
+
+        // Register the scope
+        OAuthScopeRegistry scopeRegistry = getService(OAuthScopeRegistry.class);
+        scopeRegistry.registerScopes(oAuthMetaData.getAPI(), YahooOAuthScope.values());
+
+        /*
+         * Register event handler
+         */
+        final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
+        serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.TOPIC_LAST_SESSION);
+        registerService(EventHandler.class, new YahooAccessEventHandler(), serviceProperties);
+
+        // Register the update task
+        // track(DatabaseService.class, new DatabaseUpdateTaskServiceTracker(context));
+
         LOG.info("YahooService was started.");
     }
 
