@@ -55,11 +55,15 @@ import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import com.openexchange.exception.OXException;
-import com.openexchange.oauth.API;
+import com.openexchange.oauth.KnownApi;
 import com.openexchange.oauth.OAuthAccount;
 import com.openexchange.oauth.OAuthExceptionCodes;
 import com.openexchange.oauth.OAuthService;
 import com.openexchange.oauth.OAuthServiceMetaData;
+import com.openexchange.oauth.access.InitializeCallable;
+import com.openexchange.oauth.access.OAuthAccess;
+import com.openexchange.oauth.access.OAuthAccessRegistry;
+import com.openexchange.oauth.access.OAuthAccessRegistryService;
 import com.openexchange.osgi.HousekeepingActivator;
 import com.openexchange.session.Session;
 import com.openexchange.sessiond.SessiondEventConstants;
@@ -71,7 +75,6 @@ import com.openexchange.xing.access.internal.Services;
 import com.openexchange.xing.access.internal.XingEventHandler;
 import com.openexchange.xing.access.internal.XingOAuthAccessImpl;
 
-
 /**
  * {@link XingOAuthAccessActivator}
  *
@@ -90,7 +93,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
 
     @Override
     protected Class<?>[] getNeededServices() {
-        return new Class<?>[] { SessiondService.class, OAuthService.class };
+        return new Class<?>[] { SessiondService.class, OAuthService.class, OAuthAccessRegistryService.class };
     }
 
     @Override
@@ -124,14 +127,27 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
             public XingOAuthAccess accessFor(final int oauthAccountId, final Session session) throws OXException {
                 final OAuthService oAuthService = getService(OAuthService.class);
                 final OAuthAccount oAuthAccount = oAuthService.getAccount(oauthAccountId, session, session.getUserId(), session.getContextId());
-                return XingOAuthAccessImpl.accessFor(oAuthAccount, session);
+
+                OAuthAccessRegistryService registryService = Services.getService(OAuthAccessRegistryService.class);
+                OAuthAccessRegistry registry = registryService.get(KnownApi.XING.getFullName());
+                OAuthAccess oAuthAccess = registry.get(session.getContextId(), session.getUserId());
+                if (oAuthAccess == null) {
+                    // Create
+                    XingOAuthAccessImpl newInstance = new XingOAuthAccessImpl(session, oAuthAccount);
+                    // Add to registry & return
+                    oAuthAccess = registry.addIfAbsent(session.getContextId(), session.getUserId(), newInstance, new InitializeCallable(newInstance));
+                    if (null == oAuthAccess) {
+                        oAuthAccess = newInstance;
+                    }
+                }
+                return (XingOAuthAccessImpl) oAuthAccess;
             }
 
             @Override
             public int getXingOAuthAccount(Session session) throws OXException {
                 try {
                     final OAuthService oAuthService = getService(OAuthService.class);
-                    return oAuthService.getDefaultAccount(API.XING, session).getId();
+                    return oAuthService.getDefaultAccount(KnownApi.XING, session).getId();
                 } catch (OXException e) {
                     if (OAuthExceptionCodes.ACCOUNT_NOT_FOUND.equals(e)) {
                         throw XingExceptionCodes.NO_OAUTH_ACCOUNT.create(e, session.getUserId(), session.getContextId());
@@ -142,7 +158,7 @@ public final class XingOAuthAccessActivator extends HousekeepingActivator {
 
             @Override
             public XingOAuthAccess accessFor(String token, String secret, Session session) throws OXException {
-                return XingOAuthAccessImpl.accessFor(session, token, secret);
+                return new XingOAuthAccessImpl(session, token, secret);
             }
         };
         providerRegistration = context.registerService(XingOAuthAccessProvider.class, provider, null);
